@@ -104,12 +104,12 @@ void filelist_encrypt( const char *src, const char *dst_dir, const char *key_dir
         if( srcname!="" ) try {
             // Seperate the prefix from the actual name, and reconnect them using the prefix_op
             bool is_dir = srcname[srcname.length()-1]==DIRSEP_C;
+            bool is_abs = autofd::is_absolute(srcname.c_str());
 
             size_t src_offset=calc_trim( srcname.c_str(), VAL(trim) );
             // Create the string for the prefix part
             std::string src_prefix(
-                prefix_op( FILENAME(src), std::string(srcname.c_str(), src_offset).c_str(),
-                    autofd::is_absolute(srcname.c_str())));
+                prefix_op( FILENAME(src), std::string(srcname.c_str(), src_offset).c_str(), is_abs));
             
             if( src_offset!=0 ) {
                 srcname = srcname.c_str()+src_offset;
@@ -151,8 +151,8 @@ void filelist_encrypt( const char *src, const char *dst_dir, const char *key_dir
                 if( VERBOSE(1) )
                     std::cerr<<opname<<" directory: "<<srcname<<std::endl;
 
-                real_dir_encrypt( src.c_str(), trim_offset, dst_dir, key_dir, rsa_key, op, opname, dstnameop,
-                        keynameop );
+                real_dir_encrypt( src.c_str(), is_abs ? 0 : trim_offset, dst_dir, key_dir, rsa_key, op,
+                        opname, dstnameop, keynameop );
             }
         } catch( const delayed_error & ) {
             error=true;
@@ -312,7 +312,10 @@ static void real_dir_encrypt( const char *src_dir, size_t rel, const char *dst_d
                  encryptfunc op, const char *opname, namefunc dstname, namefunc keyname )
 {
     // How many bytes of src_dir to skip when creating dirs under dst_dir
-    int src_offset=calc_trim( src_dir+rel, VAL(trim) )+rel; 
+    int src_offset=rel;
+    
+    if( src_offset==0 )
+        src_offset = calc_trim( src_dir, VAL(trim) ); 
     
     // Implement standard recursive descent on src_dir
     autofd::mkpath( dstname(dst_dir, src_dir+src_offset, S_IFDIR ).c_str(), 0777 );
